@@ -4,28 +4,36 @@ import threading
 import time
 import traceback
 import uuid
-from typing import List, Union
+from typing import List, Optional, Union
 
 import httpx
 
 from botoy import macro
-from botoy.config import Config
+from botoy.config import jconfig
 from botoy.log import logger
 from botoy.model import EventMsg, FriendMsg, GroupMsg
 
+from . import utils
+
 
 class Action:
     def __init__(
-        self, qq: int = None, port: int = None, host: str = None, timeout: int = 20
+        self,
+        qq: Optional[int] = None,
+        port: Optional[int] = None,
+        host: Optional[str] = None,
+        timeout: int = 20,
     ):
-        self.config = Config(host=host, port=port)
+        self.host = utils.check_schema(host or jconfig.host)
+        self.port = port or jconfig.port
+        self.address = utils.to_address(self.host, self.port)
 
-        self.qq = int(qq or self.config.qq)
+        self.qq = int(qq or jconfig.qq)  # type: ignore
 
         self.c = httpx.Client(
             headers={"Content-Type": "application/json"},
             timeout=timeout + 5,
-            base_url=self.config.address,
+            base_url=self.address,
             params={"qq": self.qq, "timeout": timeout},
         )
         self.lock = threading.Lock()
@@ -60,7 +68,7 @@ class Action:
         *,
         picUrl: str = "",
         picBase64Buf: str = "",
-        picMd5s: Union[str, List[str]] = None,
+        picMd5s: Optional[Union[str, List[str]]] = None,
         content: str = "",
         flashPic=False,
     ):
@@ -148,7 +156,7 @@ class Action:
         content: str = "",
         picUrl: str = "",
         picBase64Buf: str = "",
-        picMd5s: Union[str, List[str]] = None,
+        picMd5s: Optional[Union[str, List[str]]] = None,
         flashPic=False,
         atUser: Union[int, List[int]] = 0,
     ) -> dict:
@@ -298,7 +306,7 @@ class Action:
         *,
         picUrl: str = "",
         picBase64Buf: str = "",
-        picMd5s: Union[str, List[str]] = None,
+        picMd5s: Optional[Union[str, List[str]]] = None,
     ) -> dict:
         """发送私聊图片消息"""
         assert any([picUrl, picBase64Buf, picMd5s]), "缺少参数"
@@ -333,7 +341,7 @@ class Action:
         group: int,
         content: str,
         msgSeq: int,
-        msgTime: int = None,
+        msgTime: Optional[int] = None,
         user: int = 0,
         rawContent: str = "",
     ):
@@ -367,7 +375,7 @@ class Action:
         user: int,
         content: str,
         msgSeq: int,
-        msgTime: int = None,
+        msgTime: Optional[int] = None,
         rawContent: str = "",
     ):
         """发送回复消息, 回复好友消息
@@ -798,8 +806,8 @@ class Action:
         method: str,
         funcname: str,
         path: str,
-        payload: dict = None,
-        params: dict = None,
+        payload: Optional[dict] = None,
+        params: Optional[dict] = None,
     ) -> dict:
         """基础请求方法, 提供部分提示信息，出错返回空字典，其他返回服务端响应结果"""
         if params is not None:
@@ -864,7 +872,7 @@ class Action:
         self,
         funcname: str,
         payload: dict,
-        params: dict = None,
+        params: Optional[dict] = None,
         path: str = "/v1/LuaApiCaller",
     ) -> dict:
         """封装常用的post操作"""
@@ -875,7 +883,7 @@ class Action:
     def get(
         self,
         funcname: str,
-        params: dict = None,
+        params: Optional[dict] = None,
         path: str = "/v1/LuaApiCaller",
     ) -> dict:
         """封装get操作"""
