@@ -1,27 +1,33 @@
 import time
 import traceback
-from typing import List, Union
+from typing import List, Optional, Union
 
 import httpx
 
-from botoy import macro
-from botoy.config import Config
-from botoy.log import logger
-from botoy.model import EventMsg, FriendMsg, GroupMsg
+from . import macro, utils
+from .config import jconfig
+from .log import logger
+from .model import EventMsg, FriendMsg, GroupMsg
 
 
 class AsyncAction:
     def __init__(
-        self, qq: int = None, port: int = None, host: str = None, timeout: int = 20
+        self,
+        qq: Optional[int] = None,
+        port: Optional[int] = None,
+        host: Optional[str] = None,
+        timeout: int = 20,
     ):
-        self.config = Config(host=host, port=port)
+        self.host = utils.check_schema(host or jconfig.host)
+        self.port = port or jconfig.port
+        self.address = utils.to_address(self.host, self.port)
 
-        self.qq = int(qq or self.config.qq)
+        self.qq = int(qq or jconfig.qq)  # type: ignore
 
         self.c = httpx.AsyncClient(
             headers={"Content-Type": "application/json"},
             timeout=timeout + 5,
-            base_url=self.config.address,
+            base_url=self.address,
             params={"qq": self.qq, "timeout": timeout},
         )
 
@@ -64,7 +70,7 @@ class AsyncAction:
         *,
         picUrl: str = "",
         picBase64Buf: str = "",
-        picMd5s: Union[str, List[str]] = None,
+        picMd5s: Optional[Union[str, List[str]]] = None,
         content: str = "",
         flashPic=False,
     ):
@@ -140,7 +146,7 @@ class AsyncAction:
         content: str = "",
         picUrl: str = "",
         picBase64Buf: str = "",
-        picMd5s: Union[str, List[str]] = None,
+        picMd5s: Optional[Union[str, List[str]]] = None,
         flashPic=False,
         atUser: Union[int, List[int]] = 0,
     ) -> dict:
@@ -278,7 +284,7 @@ class AsyncAction:
         *,
         picUrl: str = "",
         picBase64Buf: str = "",
-        picMd5s: Union[str, List[str]] = None,
+        picMd5s: Optional[Union[str, List[str]]] = None,
     ) -> dict:
         """发送私聊图片消息"""
         assert any([picUrl, picBase64Buf, picMd5s]), "缺少参数"
@@ -313,7 +319,7 @@ class AsyncAction:
         group: int,
         content: str,
         msgSeq: int,
-        msgTime: int = None,
+        msgTime: Optional[int] = None,
         user: int = 0,
         rawContent: str = "",
     ):
@@ -347,7 +353,7 @@ class AsyncAction:
         user: int,
         content: str,
         msgSeq: int,
-        msgTime: int = None,
+        msgTime: Optional[int] = None,
         rawContent: str = "",
     ):
         """发送回复消息, 回复好友消息
@@ -623,8 +629,8 @@ class AsyncAction:
         method: str,
         funcname: str,
         path: str,
-        payload: dict = None,
-        params: dict = None,
+        payload: Optional[dict] = None,
+        params: Optional[dict] = None,
     ) -> dict:
         """基础请求方法, 提供部分提示信息，出错返回空字典，其他返回服务端响应结果"""
         if params is not None:
@@ -685,7 +691,7 @@ class AsyncAction:
         self,
         funcname: str,
         payload: dict,
-        params: dict = None,
+        params: Optional[dict] = None,
         path: str = "/v1/LuaApiCaller",
     ) -> dict:
         """封装常用的post操作"""
@@ -696,7 +702,7 @@ class AsyncAction:
     async def get(
         self,
         funcname: str,
-        params: dict = None,
+        params: Optional[dict] = None,
         path: str = "/v1/LuaApiCaller",
     ) -> dict:
         """封装get操作"""
