@@ -27,13 +27,13 @@ def start_scheduler():
         scheduler.start()
         logger.info("同步定时任务已启动")
     if not async_scheduler.running:
-        scheduler.configure(
+        async_scheduler.configure(
             {
                 "apscheduler.timezone": "Asia/Shanghai",
                 **(jconfig.apscheduler_config or {}),
             }
         )
-        scheduler.start()
+        async_scheduler.start()
         logger.info("异步定时任务已启动")
 
 
